# $Id: 01-new-destroy.t,v 1.3 2000/12/18 04:32:43 knok Exp $
#

use strict;
use Test;

BEGIN { plan tests => 2 }

use Search::Saryer;
my $file = 't/01-new-destroy.t';

print STDERR "\nCreate suffix array\n";
system("mksary $file");
print STDERR "Create Saryer object.\n";
my $x = Search::Saryer::new('filename' => $file);
ok(defined $x);
$x->destroy();
ok(1);
unlink("$file.ary");
